@@ -877,229 +877,6 @@ enum UntrustedMessageSource {
     Accumulation,
 }
 
-#[tokio::test(flavor = "multi_thread")]
-async fn handle_untrusted_accumulated_message() -> Result<()> {
-    let (section_auth, _, sk_set) = create_section_auth();
-
-    let sk0 = sk_set.secret_key();
-    let pk0 = sk0.public_key();
-    let chain = SecuredLinkedList::new(pk0);
-
-    let sender = *section_auth
-        .addresses()
-        .get(0)
-        .ok_or_else(|| eyre!("section_auth is empty"))?;
-
-    let section_signed_section_auth = section_signed(sk0, section_auth.clone())?;
-    let mut section = Section::new(pk0, chain, section_signed_section_auth)?;
-
-    let node = create_node(MIN_ADULT_AGE, None);
-    let node_name = node.name();
-    let (used_space, root_storage_dir) = create_test_used_space_and_root_storage()?;
-    let core = Core::new(
-        create_comm().await?,
-        node,
-        section.clone(),
-        None,
-        mpsc::channel(TEST_EVENT_CHANNEL_SIZE).0,
-        used_space,
-        root_storage_dir,
-    )
-    .await?;
-
-    // just any non-AE message here as they are handle differently
-    let original_node_msg = SystemMsg::NodeMsgError {
-        error: crate::messaging::data::Error::DataExists,
-        correlation_id: MessageId::new(),
-    };
-
-    let dispatcher = Dispatcher::new(core);
-
-    // Create a any message signed by a key not known to the node.
-    let sk1 = bls::SecretKey::random();
-    let pk1 = sk1.public_key();
-    let unknown_chain = SecuredLinkedList::new(pk1);
-    // we corrupt the section chain so it's unknown
-    section.chain = unknown_chain;
-
-    let payload = WireMsg::serialize_msg_payload(&original_node_msg)?;
-    let expected_recipients = vec![sender];
-    let msg_kind = MsgKind::SectionAuthMsg(MsgKindSectionAuth {
-        src_name: Prefix::default().name(),
-        sig: KeyedSig {
-            public_key: pk1,
-            signature: sk1.sign(&payload),
-        },
-    });
-
-    let dst_location = DstLocation::Section {
-        name: node_name,
-        section_pk: pk0,
-    };
-    let wire_msg = WireMsg::new_msg(MessageId::new(), payload, msg_kind, dst_location)?;
-
-    let commands = dispatcher
-        .handle_command(Command::HandleMessage {
-            sender,
-            wire_msg,
-            original_bytes: None,
-        })
-        .await?;
-
-    let mut bounce_sent = false;
-
-    for command in commands {
-        println!("COMMAND: {:?}", command);
-        let (recipients, wire_msg) = if let Command::SendMessage {
-            recipients,
-            wire_msg,
-            ..
-        } = command
-        {
-            (recipients, wire_msg)
-        } else {
-            continue;
-        };
-
-        if let Ok(MessageType::System {
-            msg:
-                SystemMsg::BouncedUntrustedMessage {
-                    msg,
-                    dst_section_pk,
-                },
-            ..
-        }) = wire_msg.into_message()
-        {
-            assert_eq!(
-                recipients
-                    .into_iter()
-                    .map(|recp| recp.1)
-                    .collect::<Vec<_>>(),
-                expected_recipients
-            );
-            assert_eq!(*msg, original_node_msg);
-            assert_eq!(dst_section_pk, pk0);
-
-            bounce_sent = true;
-        }
-    }
-
-    assert!(bounce_sent);
-
-    Ok(())
-}
-
-#[tokio::test(flavor = "multi_thread")]
-// A message has been bounced back to us as it was not trusted.
-// 1. Check the message we send an AE-Update response.
-// // nop// 2. Check the original was bounced
-async fn check_we_send_ae_update_when_msg_bounced_as_untrusted() -> Result<()> {
-    let sk_set0 = SecretKeySet::random();
-    let pk0 = sk_set0.public_keys().public_key();
-
-    let (section_auth, mut nodes, sk_set1) =
-        gen_section_authority_provider(Prefix::default(), ELDER_SIZE);
-
-    // Create section chain with two keys.
-    let pk1 = sk_set1.secret_key().public_key();
-    let pk1_signature = sk_set0.key.sign(&bincode::serialize(&pk1)?);
-
-    let mut chain = SecuredLinkedList::new(pk0);
-    let _ = chain.insert(&pk0, pk1, pk1_signature);
-
-    let section_signed_section_auth = section_signed(sk_set1.secret_key(), section_auth)?;
-    let section = Section::new(pk0, chain.clone(), section_signed_section_auth)?;
-    let section_key_share = create_section_key_share(&sk_set1, 0);
-
-    let node = nodes.remove(0);
-
-    // Create the original message whose bounce we want to test.
-    let other_node = Node::new(
-        ed25519::gen_keypair(&Prefix::default().range_inclusive(), MIN_ADULT_AGE),
-        gen_addr(),
-    );
-
-    // Create our node.
-    let (used_space, root_storage_dir) = create_test_used_space_and_root_storage()?;
-    let core = Core::new(
-        create_comm().await?,
-        node,
-        section.clone(),
-        Some(section_key_share),
-        mpsc::channel(TEST_EVENT_CHANNEL_SIZE).0,
-        used_space,
-        root_storage_dir,
-    )
-    .await?;
-
-    // just any non-AE message here as they are handle differently
-    let original_node_msg = SystemMsg::NodeMsgError {
-        error: crate::messaging::data::Error::DataExists,
-        correlation_id: MessageId::new(),
-    };
-
-    let dispatcher = Dispatcher::new(core);
-
-    // Create the bounced message, indicating the last key the peer knows is `pk0`
-    let bounced_wire_msg = WireMsg::single_src(
-        &other_node,
-        DstLocation::Node {
-            name: XorName::from(PublicKey::Bls(pk1)),
-            section_pk: pk1,
-        },
-        SystemMsg::BouncedUntrustedMessage {
-            msg: Box::new(original_node_msg.clone()),
-            dst_section_pk: pk0,
-        },
-        pk0,
-    )?;
-
-    let commands = get_internal_commands(
-        Command::HandleMessage {
-            sender: other_node.addr,
-            wire_msg: bounced_wire_msg,
-            original_bytes: None,
-        },
-        &dispatcher,
-    )
-    .await?;
-
-    let mut ae_update_sent = false;
-
-    for command in commands {
-        let (recipients, wire_msg) = match command {
-            Command::SendMessage {
-                recipients,
-                wire_msg,
-                ..
-            } => (recipients, wire_msg),
-            _ => continue,
-        };
-
-        match wire_msg.into_message() {
-            // check we are firing out an AE-update
-            Ok(MessageType::System {
-                msg: SystemMsg::AntiEntropyUpdate { proof_chain, .. },
-                dst_location,
-                ..
-            }) => {
-                assert_eq!(recipients, [(other_node.name(), other_node.addr)]);
-                assert_eq!(proof_chain.len(), 2);
-
-                assert_eq!(dst_location.section_pk(), Some(pk0));
-
-                ae_update_sent = true;
-            }
-
-            _ => continue,
-        }
-    }
-
-    assert!(ae_update_sent);
-
-    Ok(())
-}
-
 #[tokio::test(flavor = "multi_thread")]
 // Checking when we get an untrusted AE info to a section, if it's ahead of us we should handle it.
 async fn ae_msg_from_the_future_is_handled() -> Result<()> {
